import 'package:flutter/material.dart';
import 'package:vegigo2_ui_common/util/colors.dart' as color;
import 'package:vegigo2_ui_common/util/size_config.dart';

class DualText extends StatelessWidget {
  final String text1;
  final String text2;
  final TextStyle style1;
  final TextStyle style2;
  final bool isVertical;
  final double spacing;

  DualText({
    @required this.text1,
    @required this.text2,
    this.style1,
    this.style2,
    this.isVertical = false,
    this.spacing = 5.0
  });
  
  @override
  Widget build(BuildContext context) {
    return isVertical ? verticalWidget(context) : horizontalWidget(context);
  }

  Widget horizontalWidget(BuildContext context){
    return Row(
      children: <Widget>[
        Text(text1,
          style: style1 ?? Theme.of(context).textTheme.headline3.copyWith(color: Colors.white),
        ),
        SizedBox(width: spacing * SizeConfig.widthMultiplier),
        Text(text2,
          style: style2 ?? Theme.of(context).textTheme.headline3.copyWith(color: color.ADMIN_SECONDARY),
        )
      ],
    );
  }

  Widget verticalWidget(BuildContext context){
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: <Widget>[
        Text(text1,
          style: style1 ?? Theme.of(context).textTheme.headline3.copyWith(color: Colors.white),
        ),
        SizedBox(width: spacing * SizeConfig.heightMultiplier),
        Text(text2,
          style: style2 ?? Theme.of(context).textTheme.headline3.copyWith(color: color.ADMIN_SECONDARY),
        )
      ],
    );
  }
}